@@ -180,7 +180,7 @@ func runCfg(n *node, f *frame) {
 			if oNode == nil {
 				oNode = n
 			}
-			fmt.Println(oNode.cfgErrorf("panic"))
+			fmt.Fprintln(n.interp.stderr, oNode.cfgErrorf("panic"))
 			f.mutex.Unlock()
 			panic(f.recovered)
 		}
@@ -632,6 +632,7 @@ func assign(n *node) {
 	}
 
 	if n.nleft == 1 {
+		// Single assign operation.
 		switch s, d, i := svalue[0], dvalue[0], ivalue[0]; {
 		case n.child[0].ident == "_":
 			n.exec = func(f *frame) bltn {
@@ -642,51 +643,84 @@ func assign(n *node) {
 				d(f).SetMapIndex(i(f), s(f))
 				return next
 			}
+		case n.kind == defineStmt:
+			l := n.level
+			ind := n.findex
+			n.exec = func(f *frame) bltn {
+				data := getFrame(f, l).data
+				data[ind] = reflect.New(data[ind].Type()).Elem()
+				data[ind].Set(s(f))
+				return next
+			}
 		default:
 			n.exec = func(f *frame) bltn {
 				d(f).Set(s(f))
 				return next
 			}
 		}
-	} else {
-		types := make([]reflect.Type, n.nright)
-		for i := range types {
-			var t reflect.Type
-			switch typ := n.child[sbase+i].typ; typ.cat {
-			case funcT:
-				t = reflect.TypeOf((*node)(nil))
-			case interfaceT:
-				t = reflect.TypeOf((*valueInterface)(nil)).Elem()
-			default:
-				t = typ.TypeOf()
-			}
-			types[i] = t
-		}
+		return
+	}
 
-		// To handle swap in multi-assign:
-		// evaluate and copy all values in assign right hand side into temporary
-		// then evaluate assign left hand side and copy temporary into it
+	// Multi assign operation.
+	types := make([]reflect.Type, n.nright)
+	index := make([]int, n.nright)
+	level := make([]int, n.nright)
+
+	for i := range types {
+		var t reflect.Type
+		switch typ := n.child[sbase+i].typ; typ.cat {
+		case funcT:
+			t = reflect.TypeOf((*node)(nil))
+		case interfaceT:
+			t = reflect.TypeOf((*valueInterface)(nil)).Elem()
+		default:
+			t = typ.TypeOf()
+		}
+		types[i] = t
+		index[i] = n.child[i].findex
+		level[i] = n.child[i].level
+	}
+
+	if n.kind == defineStmt {
+		// Handle a multiple var declararation / assign. It cannot be a swap.
 		n.exec = func(f *frame) bltn {
-			t := make([]reflect.Value, len(svalue))
 			for i, s := range svalue {
 				if n.child[i].ident == "_" {
 					continue
 				}
-				t[i] = reflect.New(types[i]).Elem()
-				t[i].Set(s(f))
-			}
-			for i, d := range dvalue {
-				if n.child[i].ident == "_" {
-					continue
-				}
-				if j := ivalue[i]; j != nil {
-					d(f).SetMapIndex(j(f), t[i]) // Assign a map entry
-				} else {
-					d(f).Set(t[i]) // Assign a var or array/slice entry
-				}
+				data := getFrame(f, level[i]).data
+				j := index[i]
+				data[j] = reflect.New(data[j].Type()).Elem()
+				data[j].Set(s(f))
 			}
 			return next
 		}
+		return
+	}
+
+	// To handle possible swap in multi-assign:
+	// evaluate and copy all values in assign right hand side into temporary
+	// then evaluate assign left hand side and copy temporary into it
+	n.exec = func(f *frame) bltn {
+		t := make([]reflect.Value, len(svalue))
+		for i, s := range svalue {
+			if n.child[i].ident == "_" {
+				continue
+			}
+			t[i] = reflect.New(types[i]).Elem()
+			t[i].Set(s(f))
+		}
+		for i, d := range dvalue {
+			if n.child[i].ident == "_" {
+				continue
+			}
+			if j := ivalue[i]; j != nil {
+				d(f).SetMapIndex(j(f), t[i]) // Assign a map entry
+			} else {
+				d(f).Set(t[i]) // Assign a var or array/slice entry
+			}
+		}
+		return next
 	}
 }
 
@@ -892,7 +926,7 @@ func genFunctionWrapper(n *node) func(*frame) reflect.Value {
 	funcType := n.typ.TypeOf()
 
 	return func(f *frame) reflect.Value {
-		if n.frame != nil { // Use closure context if defined
+		if n.frame != nil { // Use closure context if defined.
 			f = n.frame
 		}
 		return reflect.MakeFunc(funcType, func(in []reflect.Value) []reflect.Value {
@@ -903,7 +937,7 @@ func genFunctionWrapper(n *node) func(*frame) reflect.Value {
 				d[i] = reflect.New(t).Elem()
 			}
 
-			// Copy method receiver as first argument, if defined
+			// Copy method receiver as first argument, if defined.
 			if rcvr != nil {
 				src, dest := rcvr(f), d[numRet]
 				if src.Type().Kind() != dest.Type().Kind() {
@@ -919,7 +953,7 @@ func genFunctionWrapper(n *node) func(*frame) reflect.Value {
 				d = d[numRet:]
 			}
 
-			// Copy function input arguments in local frame
+			// Copy function input arguments in local frame.
 			for i, arg := range in {
 				typ := def.typ.arg[i]
 				switch {
@@ -936,7 +970,7 @@ func genFunctionWrapper(n *node) func(*frame) reflect.Value {
 				}
 			}
 
-			// Interpreter code execution
+			// Interpreter code execution.
 			runCfg(start, fr)
 
 			result := fr.data[:numRet]
@@ -1300,16 +1334,18 @@ func callBin(n *node) {
 	tnext := getExec(n.tnext)
 	fnext := getExec(n.fnext)
 	child := n.child[1:]
-	value := genValue(n.child[0])
+	c0 := n.child[0]
+	value := genValue(c0)
 	var values []func(*frame) reflect.Value
-	funcType := n.child[0].typ.rtype
+	funcType := c0.typ.rtype
+	wt := wrappedType(c0)
 	variadic := -1
 	if funcType.IsVariadic() {
 		variadic = funcType.NumIn() - 1
 	}
 	// A method signature obtained from reflect.Type includes receiver as 1st arg, except for interface types.
 	rcvrOffset := 0
-	if recv := n.child[0].recv; recv != nil && !isInterface(recv.node.typ) {
+	if recv := c0.recv; recv != nil && !isInterface(recv.node.typ) {
 		if variadic > 0 || funcType.NumIn() > len(child) {
 			rcvrOffset = 1
 		}
@@ -1358,6 +1394,11 @@ func callBin(n *node) {
 				}
 			}
 
+			if wt != nil && wt.arg[i].cat == interfaceT {
+				values = append(values, genValueInterface(c))
+				break
+			}
+
 			switch c.typ.cat {
 			case funcT:
 				values = append(values, genFunctionWrapper(c))
@@ -1759,12 +1800,14 @@ func getIndexMap2(n *node) {
 	}
 }
 
+const fork = true // Duplicate frame in frame.clone().
+
 func getFunc(n *node) {
 	dest := genValue(n)
 	next := getExec(n.tnext)
 
 	n.exec = func(f *frame) bltn {
-		fr := f.clone()
+		fr := f.clone(fork)
 		nod := *n
 		nod.val = &nod
 		nod.frame = fr
@@ -1779,7 +1822,7 @@ func getMethod(n *node) {
 	next := getExec(n.tnext)
 
 	n.exec = func(f *frame) bltn {
-		fr := f.clone()
+		fr := f.clone(!fork)
 		nod := *(n.val.(*node))
 		nod.val = &nod
 		nod.recv = n.recv
@@ -1815,7 +1858,7 @@ func getMethodByName(n *node) {
 			return next
 		}
 		m, li := val.node.typ.lookupMethod(name)
-		fr := f.clone()
+		fr := f.clone(!fork)
 		nod := *m
 		nod.val = &nod
 		nod.recv = &receiver{nil, val.value, li}
@@ -2522,7 +2565,7 @@ func doComposite(n *node, hasType bool, keyed bool) {
 		case val.typ.cat == nilT:
 			values[fieldIndex] = func(*frame) reflect.Value { return reflect.New(rft).Elem() }
 		case val.typ.cat == funcT:
-			values[fieldIndex] = genFunctionWrapper(val)
+			values[fieldIndex] = genValueAsFunctionWrapper(val)
 		case isArray(val.typ) && val.typ.val != nil && val.typ.val.cat == interfaceT:
 			values[fieldIndex] = genValueInterfaceArray(val)
 		case isRecursiveType(ft, rft):
